package com.zy.bms.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.zy.bms.common.Constant;
import com.zy.bms.common.enums.DeviceType;
import com.zy.bms.entity.DeviceBase;
import com.zy.bms.entity.Group;
import com.zy.bms.entity.lp.LpInfoState;
import com.zy.bms.entity.ubi.UbiInfoState;
import com.zy.bms.pojo.vo.wx.SimpleDevicesVO;
import com.zy.bms.service.IDeviceBaseService;
import com.zy.bms.service.IGroupService;
import com.zy.bms.service.IUserPrivilegeService;
import com.zy.bms.service.IWxApiService;
import com.zy.bms.service.lp.ILpInfoStateService;
import com.zy.bms.service.ubi.IUbiInfoStateService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * 设备静态信息 服务实现类
 *
 * @author yangxiaokun
 * @since 2021-06-01
 */
@Service
public class WxApiServiceImpl implements IWxApiService {

    @Resource
    private IDeviceBaseService deviceBaseService;

    @Resource
    private IUbiInfoStateService ubiInfoStateService;

    @Resource
    private ILpInfoStateService lpInfoStateService;

    @Resource
    private IUserPrivilegeService userPrivilegeService;

    @Resource
    private IGroupService groupService;


    @Override
    public List listFullInfoByGroupId(Integer userId, String groupId) {
        //是否有权限
        boolean flag = userPrivilegeService.hasPrivilege(userId, groupId);
        if (!flag) return new ArrayList<>();
        //设备组
        Group group = groupService.getByCode(groupId);
        //普适型设备
        if (DeviceType.UBI.value.equals(group.getType())) {
            return ubiInfoStateService.listFullByGroupId(groupId);
        }
        //路牌设备
        if (DeviceType.LP.value.equals(group.getType())) {
            return lpInfoStateService.listFullByGroupId(groupId);
        }
        return new ArrayList();
    }

    @Override
    public List<SimpleDevicesVO> listSimpleInfoByGroupId(Integer userId, String groupId) {
        //是否有权限
        boolean flag = userPrivilegeService.hasPrivilege(userId, groupId);
        if (!flag) return new ArrayList<>();
        //设备组
        Group group = groupService.getByCode(groupId);
        //普适型设备
        if (DeviceType.UBI.value.equals(group.getType())) {
            return ubiInfoStateService.listSimpleByGroupId(groupId);
        }
        //路牌设备
        if (DeviceType.LP.value.equals(group.getType())) {
            return lpInfoStateService.listSimpleByGroupId(groupId);
        }
        return new ArrayList<>();
    }

    @Override
    public Object getDeviceByOpenNum(String openNum) {
        String type = deviceBaseService.getOne(new QueryWrapper<DeviceBase>().eq("open_num", openNum)).getType();
        if (DeviceType.UBI.value.equals(type)) {
            return ubiInfoStateService.getOne(new QueryWrapper<UbiInfoState>().eq("open_num", openNum));
        }
        if (DeviceType.LP.value.equals(type)) {
            return lpInfoStateService.getOne(new QueryWrapper<LpInfoState>().eq("open_num", openNum));
        }
        return null;
    }
}
